# -*- coding: utf-8 -*-
import logging
import cherrypy
from cherrypy.process.plugins import SimplePlugin

__all__ = ['SessionAuthenticationPlugin']

logger = logging.getLogger(__name__)


class SessionAuthenticationPlugin(SimplePlugin):
    def __init__(self, bus, identity_key='uid'):
        """
        This plugin implements session bases user authentication.
        """
        SimplePlugin.__init__(self, bus)
        self.identity_key = identity_key

    def start(self):
        self.bus.log('Starting up SessionAuthentication')
        self.bus.subscribe("get-identity", self.get_identity)

    def stop(self):
        self.bus.log('Stopping down SessionAuthentication')
        self.bus.unsubscribe("get-identity", self.get_identity)

    def get_identity(self):
        """
        Get user identity
        """
        return cherrypy.session.get(self.identity_key, '_guest')
